@@ -1,6 +1,6 @@
 package Net::Kubernetes;
 # ABSTRACT: An object oriented interface to the REST API's provided by kubernetes
-$Net::Kubernetes::VERSION = '0.17';
+$Net::Kubernetes::VERSION = '0.18';
 use Moose;
 require Net::Kubernetes::Namespace;
 require LWP::UserAgent;
@@ -11,10 +11,9 @@ use MIME::Base64;
 require Net::Kubernetes::Exception;
 
 
-
 with 'Net::Kubernetes::Role::APIAccess';
 with 'Net::Kubernetes::Role::ResourceLister';
-
+with 'Net::Kubernetes::Role::ResourceFetcher';
 
 
 has 'default_namespace' => (
@@ -61,18 +60,55 @@ sub list_nodes {
 
 	my $res = $self->ua->request($self->create_request(GET => $uri));
 	if ($res->is_success) {
-		my $event_list = $self->json->decode($res->content);
-		my(@events)=();
-		foreach my $service (@{ $event_list->{items}}){
-			$service->{apiVersion} = $event_list->{apiVersion};
-			push @events, $self->create_resource_object($service, 'Node');
+		my $node_list = $self->json->decode($res->content);
+		my(@nodes)=();
+		foreach my $node (@{ $node_list->{items}}){
+			$node->{apiVersion} = $node_list->{apiVersion};
+			push @nodes, $self->create_resource_object($node, 'Node');
 		}
-		return wantarray ? @events : \@events;
+		return wantarray ? @nodes : \@nodes;
 	}else{
 		Net::Kubernetes::Exception->throw(code=>$res->code, message=>$res->message);
 	}
 }
 
+sub get_node {
+	my($self, $name) = @_;
+	Net::Kubernetes::Exception->throw(message=>"Missing required parameter 'name'") if(! defined $name || ! length $name);
+	return $self->get_resource_by_name($name, 'nodes');
+}
+
+
+sub list_service_accounts {
+	my $self = shift;
+	my(%options);
+	if (ref($_[0])) {
+		%options = %{ $_[0] };
+	}else{
+		%options = @_;
+	}
+
+	my $uri = URI->new($self->path.'/serviceaccounts');
+	my(%form) = ();
+	$form{labelSelector}=$self->_build_selector_from_hash($options{labels}) if (exists $options{labels});
+	$form{fieldSelector}=$self->_build_selector_from_hash($options{fields}) if (exists $options{fields});
+	$uri->query_form(%form);
+
+	my $res = $self->ua->request($self->create_request(GET => $uri));
+	if ($res->is_success) {
+		my $sa_list = $self->json->decode($res->content);
+		my(@saccs)=();
+		foreach my $sacc (@{ $sa_list->{items}}){
+			$sacc->{apiVersion} = $sa_list->{apiVersion};
+			push @saccs, $self->create_resource_object($sacc, 'ServiceAccount');
+		}
+		return wantarray ? @saccs : \@saccs;
+	}else{
+		Net::Kubernetes::Exception->throw(code=>$res->code, message=>$res->message);
+	}
+}
+
+
 sub _get_default_namespace {
 	my($self) = @_;
 	return $self->get_namespace('default');
@@ -94,7 +130,7 @@ Net::Kubernetes - An object oriented interface to the REST API's provided by kub
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 SYNOPSIS
 
@@ -172,11 +208,15 @@ Delegates automatically to L<Net::Kubernetes::Namespace> via $self->get_namespac
 
 returns a list of L<Net::Kubernetes::Resource::Node>s
 
+=head2 list_service_accounts([label=>{label=>value}], [fields=>{field=>value}])
+
+returns a list of L<Net::Kubernetes::Resource::Service>s
+
 =begin html
 
 <h2>Build Status</h2>
 
-<img src="https://travis-ci.org/perljedi/net-kubernetes.svg?branch=release-0.17" />
+<img src="https://travis-ci.org/perljedi/net-kubernetes.svg?branch=release-0.18" />
 
 =end html
 
@@ -216,6 +256,8 @@ L<Net::Kubernetes::Resource|Net::Kubernetes::Resource>
 
 =item * L<Net::Kubernetes::Role::ResourceFactory>
 
+=item * L<Net::Kubernetes::Role::ResourceFetcher>
+
 =item * L<Net::Kubernetes::Role::ResourceLister>
 
 =back
