@@ -1,6 +1,6 @@
 package Net::Kubernetes::Namespace;
 # ABSTRACT: Provides access to kubernetes respources within a single namespace.
-$Net::Kubernetes::Namespace::VERSION = '0.17';
+$Net::Kubernetes::Namespace::VERSION = '0.18';
 use Moose;
 use MooseX::Aliases;
 use syntax 'try';
@@ -8,7 +8,7 @@ use syntax 'try';
 has namespace => (
 	is       => 'ro',
 	isa      => 'Str',
-	required => 0,	
+	required => 0,
 );
 
 has _namespace_data => (
@@ -21,6 +21,8 @@ with 'Net::Kubernetes::Role::APIAccess';
 with 'Net::Kubernetes::Role::ResourceLister';
 with 'Net::Kubernetes::Role::ResourceCreator';
 with 'Net::Kubernetes::Role::ResourceFactory';
+with 'Net::Kubernetes::Role::ResourceFetcher';
+with 'Net::Kubernetes::Role::SecretBuilder';
 
 
 sub get_secret {
@@ -48,25 +50,7 @@ sub get_replication_controller {
 }
 alias get_rc => 'get_replication_controller';
 
-
-sub get_resource_by_name {
-	my($self, $name, $type) = @_;
-	my($res) = $self->ua->request($self->create_request(GET => $self->path.'/'.$type.'/'.$name));
-	if ($res->is_success) {
-		return $self->create_resource_object($self->json->decode($res->content));
-	}
-	else {
-		my $message;
-		try{
-			my $obj = $self->json->decode($res->content);
-			$message = $obj->{message};
-		}
-		catch($e) {
-			$message = $res->message;
-		}
-		Net::Kubernetes::Exception->throw(code=>$res->code, message=>$message);
-	}
-}
+return 42;
 
 __END__
 
@@ -80,7 +64,7 @@ Net::Kubernetes::Namespace - Provides access to kubernetes respources within a s
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 METHODS
 
@@ -126,8 +110,12 @@ L<Net::Kubernetes|Net::Kubernetes>
 
 =item * L<Net::Kubernetes::Role::ResourceFactory>
 
+=item * L<Net::Kubernetes::Role::ResourceFetcher>
+
 =item * L<Net::Kubernetes::Role::ResourceLister>
 
+=item * L<Net::Kubernetes::Role::SecretBuilder>
+
 =back
 
 =cut
